==> model-1.2-sources.jar: org/ow2/weblab/core/model/ObjectFactory.java <==

package org.ow2.weblab.core.model;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.ow2.weblab.core.model package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TemporalSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "TemporalSegment");
    private final static QName _ResultSet_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ResultSet");
    private final static QName _LowLevelDescriptor_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "LowLevelDescriptor");
    private final static QName _Video_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Video");
    private final static QName _Coordinate_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Coordinate");
    private final static QName _ComposedResource_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ComposedResource");
    private final static QName _SimilarityQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "SimilarityQuery");
    private final static QName _Image_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Image");
    private final static QName _Segment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Segment");
    private final static QName _ComposedQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ComposedQuery");
    private final static QName _MediaUnit_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "MediaUnit");
    private final static QName _Query_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Query");
    private final static QName _ElementaryQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ElementaryQuery");
    private final static QName _Audio_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Audio");
    private final static QName _Text_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Text");
    private final static QName _Annotation_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Annotation");
    private final static QName _LinearSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "LinearSegment");
    private final static QName _PieceOfKnowledge_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "PieceOfKnowledge");
    private final static QName _Resource_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Resource");
    private final static QName _Document_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Document");
    private final static QName _StringQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "StringQuery");
    private final static QName _SpatialSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "SpatialSegment");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.ow2.weblab.core.model
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TemporalSegment }
     * 
     */
    public TemporalSegment createTemporalSegment() {
        return new TemporalSegment();
    }

    /**
     * Create an instance of {@link LowLevelDescriptor }
     * 
     */
    public LowLevelDescriptor createLowLevelDescriptor() {
        return new LowLevelDescriptor();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link ResultSet }
     * 
     */
    public ResultSet createResultSet() {
        return new ResultSet();
    }

    /**
     * Create an instance of {@link Video }
     * 
     */
    public Video createVideo() {
        return new Video();
    }

    /**
     * Create an instance of {@link Coordinate }
     * 
     */
    public Coordinate createCoordinate() {
        return new Coordinate();
    }

    /**
     * Create an instance of {@link Image }
     * 
     */
    public Image createImage() {
        return new Image();
    }

    /**
     * Create an instance of {@link ComposedResource }
     * 
     */
    public ComposedResource createComposedResource() {
        return new ComposedResource();
    }

    /**
     * Create an instance of {@link ComposedQuery }
     * 
     */
    public ComposedQuery createComposedQuery() {
        return new ComposedQuery();
    }

    /**
     * Create an instance of {@link SpatialSegment }
     * 
     */
    public SpatialSegment createSpatialSegment() {
        return new SpatialSegment();
    }

    /**
     * Create an instance of {@link StringQuery }
     * 
     */
    public StringQuery createStringQuery() {
        return new StringQuery();
    }

    /**
     * Create an instance of {@link PieceOfKnowledge }
     * 
     */
    public PieceOfKnowledge createPieceOfKnowledge() {
        return new PieceOfKnowledge();
    }

    /**
     * Create an instance of {@link LinearSegment }
     * 
     */
    public LinearSegment createLinearSegment() {
        return new LinearSegment();
    }

    /**
     * Create an instance of {@link Audio }
     * 
     */
    public Audio createAudio() {
        return new Audio();
    }

    /**
     * Create an instance of {@link Text }
     * 
     */
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link Annotation }
     * 
     */
    public Annotation createAnnotation() {
        return new Annotation();
    }

    /**
     * Create an instance of {@link SimilarityQuery }
     * 
     */
    public SimilarityQuery createSimilarityQuery() {
        return new SimilarityQuery();
    }

    /**
     * Create an instance of {@link Document }
     * 
     */
    public Document createDocument() {
        return new Document();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TemporalSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "TemporalSegment")
    public JAXBElement<TemporalSegment> createTemporalSegment(TemporalSegment value) {
        return new JAXBElement<TemporalSegment>(_TemporalSegment_QNAME, TemporalSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ResultSet }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ResultSet")
    public JAXBElement<ResultSet> createResultSet(ResultSet value) {
        return new JAXBElement<ResultSet>(_ResultSet_QNAME, ResultSet.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LowLevelDescriptor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "LowLevelDescriptor")
    public JAXBElement<LowLevelDescriptor> createLowLevelDescriptor(LowLevelDescriptor value) {
        return new JAXBElement<LowLevelDescriptor>(_LowLevelDescriptor_QNAME, LowLevelDescriptor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Video }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Video")
    public JAXBElement<Video> createVideo(Video value) {
        return new JAXBElement<Video>(_Video_QNAME, Video.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Coordinate }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Coordinate")
    public JAXBElement<Coordinate> createCoordinate(Coordinate value) {
        return new JAXBElement<Coordinate>(_Coordinate_QNAME, Coordinate.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ComposedResource }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ComposedResource")
    public JAXBElement<ComposedResource> createComposedResource(ComposedResource value) {
        return new JAXBElement<ComposedResource>(_ComposedResource_QNAME, ComposedResource.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimilarityQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "SimilarityQuery")
    public JAXBElement<SimilarityQuery> createSimilarityQuery(SimilarityQuery value) {
        return new JAXBElement<SimilarityQuery>(_SimilarityQuery_QNAME, SimilarityQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Image }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Image")
    public JAXBElement<Image> createImage(Image value) {
        return new JAXBElement<Image>(_Image_QNAME, Image.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Segment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Segment")
    public JAXBElement<Segment> createSegment(Segment value) {
        return new JAXBElement<Segment>(_Segment_QNAME, Segment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ComposedQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ComposedQuery")
    public JAXBElement<ComposedQuery> createComposedQuery(ComposedQuery value) {
        return new JAXBElement<ComposedQuery>(_ComposedQuery_QNAME, ComposedQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MediaUnit }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "MediaUnit")
    public JAXBElement<MediaUnit> createMediaUnit(MediaUnit value) {
        return new JAXBElement<MediaUnit>(_MediaUnit_QNAME, MediaUnit.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Query }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Query")
    public JAXBElement<Query> createQuery(Query value) {
        return new JAXBElement<Query>(_Query_QNAME, Query.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ElementaryQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ElementaryQuery")
    public JAXBElement<ElementaryQuery> createElementaryQuery(ElementaryQuery value) {
        return new JAXBElement<ElementaryQuery>(_ElementaryQuery_QNAME, ElementaryQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Audio }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Audio")
    public JAXBElement<Audio> createAudio(Audio value) {
        return new JAXBElement<Audio>(_Audio_QNAME, Audio.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Text }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Text")
    public JAXBElement<Text> createText(Text value) {
        return new JAXBElement<Text>(_Text_QNAME, Text.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Annotation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Annotation")
    public JAXBElement<Annotation> createAnnotation(Annotation value) {
        return new JAXBElement<Annotation>(_Annotation_QNAME, Annotation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LinearSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "LinearSegment")
    public JAXBElement<LinearSegment> createLinearSegment(LinearSegment value) {
        return new JAXBElement<LinearSegment>(_LinearSegment_QNAME, LinearSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PieceOfKnowledge }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "PieceOfKnowledge")
    public JAXBElement<PieceOfKnowledge> createPieceOfKnowledge(PieceOfKnowledge value) {
        return new JAXBElement<PieceOfKnowledge>(_PieceOfKnowledge_QNAME, PieceOfKnowledge.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Resource }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Resource")
    public JAXBElement<Resource> createResource(Resource value) {
        return new JAXBElement<Resource>(_Resource_QNAME, Resource.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Document }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Document")
    public JAXBElement<Document> createDocument(Document value) {
        return new JAXBElement<Document>(_Document_QNAME, Document.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link StringQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "StringQuery")
    public JAXBElement<StringQuery> createStringQuery(StringQuery value) {
        return new JAXBElement<StringQuery>(_StringQuery_QNAME, StringQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SpatialSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "SpatialSegment")
    public JAXBElement<SpatialSegment> createSpatialSegment(SpatialSegment value) {
        return new JAXBElement<SpatialSegment>(_SpatialSegment_QNAME, SpatialSegment.class, null, value);
    }

}

==> model-1.2.2-sources.jar: org/ow2/weblab/core/model/ObjectFactory.java <==

package org.ow2.weblab.core.model;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.ow2.weblab.core.model package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _TrackSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "TrackSegment");
    private final static QName _TemporalSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "TemporalSegment");
    private final static QName _ResultSet_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ResultSet");
    private final static QName _LowLevelDescriptor_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "LowLevelDescriptor");
    private final static QName _Video_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Video");
    private final static QName _Coordinate_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Coordinate");
    private final static QName _ComposedResource_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ComposedResource");
    private final static QName _SimilarityQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "SimilarityQuery");
    private final static QName _Segment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Segment");
    private final static QName _Image_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Image");
    private final static QName _ComposedQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ComposedQuery");
    private final static QName _MediaUnit_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "MediaUnit");
    private final static QName _Query_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Query");
    private final static QName _ElementaryQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "ElementaryQuery");
    private final static QName _Audio_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Audio");
    private final static QName _Text_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Text");
    private final static QName _Annotation_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Annotation");
    private final static QName _LinearSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "LinearSegment");
    private final static QName _SpatioTemporalSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "SpatioTemporalSegment");
    private final static QName _PieceOfKnowledge_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "PieceOfKnowledge");
    private final static QName _Document_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Document");
    private final static QName _Resource_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "Resource");
    private final static QName _StringQuery_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "StringQuery");
    private final static QName _SpatialSegment_QNAME = new QName("http://weblab.ow2.org/core/1.2/model#", "SpatialSegment");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.ow2.weblab.core.model
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TemporalSegment }
     * 
     */
    public TemporalSegment createTemporalSegment() {
        return new TemporalSegment();
    }

    /**
     * Create an instance of {@link Coordinate }
     * 
     */
    public Coordinate createCoordinate() {
        return new Coordinate();
    }

    /**
     * Create an instance of {@link Image }
     * 
     */
    public Image createImage() {
        return new Image();
    }

    /**
     * Create an instance of {@link TrackSegment }
     * 
     */
    public TrackSegment createTrackSegment() {
        return new TrackSegment();
    }

    /**
     * Create an instance of {@link LinearSegment }
     * 
     */
    public LinearSegment createLinearSegment() {
        return new LinearSegment();
    }

    /**
     * Create an instance of {@link Text }
     * 
     */
    public Text createText() {
        return new Text();
    }

    /**
     * Create an instance of {@link SimilarityQuery }
     * 
     */
    public SimilarityQuery createSimilarityQuery() {
        return new SimilarityQuery();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Annotation }
     * 
     */
    public Annotation createAnnotation() {
        return new Annotation();
    }

    /**
     * Create an instance of {@link Document }
     * 
     */
    public Document createDocument() {
        return new Document();
    }

    /**
     * Create an instance of {@link StringQuery }
     * 
     */
    public StringQuery createStringQuery() {
        return new StringQuery();
    }

    /**
     * Create an instance of {@link ResultSet }
     * 
     */
    public ResultSet createResultSet() {
        return new ResultSet();
    }

    /**
     * Create an instance of {@link ComposedResource }
     * 
     */
    public ComposedResource createComposedResource() {
        return new ComposedResource();
    }

    /**
     * Create an instance of {@link PieceOfKnowledge }
     * 
     */
    public PieceOfKnowledge createPieceOfKnowledge() {
        return new PieceOfKnowledge();
    }

    /**
     * Create an instance of {@link Audio }
     * 
     */
    public Audio createAudio() {
        return new Audio();
    }

    /**
     * Create an instance of {@link ComposedQuery }
     * 
     */
    public ComposedQuery createComposedQuery() {
        return new ComposedQuery();
    }

    /**
     * Create an instance of {@link Video }
     * 
     */
    public Video createVideo() {
        return new Video();
    }

    /**
     * Create an instance of {@link LowLevelDescriptor }
     * 
     */
    public LowLevelDescriptor createLowLevelDescriptor() {
        return new LowLevelDescriptor();
    }

    /**
     * Create an instance of {@link SpatialSegment }
     * 
     */
    public SpatialSegment createSpatialSegment() {
        return new SpatialSegment();
    }

    /**
     * Create an instance of {@link SpatioTemporalSegment }
     * 
     */
    public SpatioTemporalSegment createSpatioTemporalSegment() {
        return new SpatioTemporalSegment();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TrackSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "TrackSegment")
    public JAXBElement<TrackSegment> createTrackSegment(TrackSegment value) {
        return new JAXBElement<TrackSegment>(_TrackSegment_QNAME, TrackSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link TemporalSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "TemporalSegment")
    public JAXBElement<TemporalSegment> createTemporalSegment(TemporalSegment value) {
        return new JAXBElement<TemporalSegment>(_TemporalSegment_QNAME, TemporalSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ResultSet }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ResultSet")
    public JAXBElement<ResultSet> createResultSet(ResultSet value) {
        return new JAXBElement<ResultSet>(_ResultSet_QNAME, ResultSet.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LowLevelDescriptor }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "LowLevelDescriptor")
    public JAXBElement<LowLevelDescriptor> createLowLevelDescriptor(LowLevelDescriptor value) {
        return new JAXBElement<LowLevelDescriptor>(_LowLevelDescriptor_QNAME, LowLevelDescriptor.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Video }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Video")
    public JAXBElement<Video> createVideo(Video value) {
        return new JAXBElement<Video>(_Video_QNAME, Video.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Coordinate }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Coordinate")
    public JAXBElement<Coordinate> createCoordinate(Coordinate value) {
        return new JAXBElement<Coordinate>(_Coordinate_QNAME, Coordinate.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ComposedResource }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ComposedResource")
    public JAXBElement<ComposedResource> createComposedResource(ComposedResource value) {
        return new JAXBElement<ComposedResource>(_ComposedResource_QNAME, ComposedResource.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SimilarityQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "SimilarityQuery")
    public JAXBElement<SimilarityQuery> createSimilarityQuery(SimilarityQuery value) {
        return new JAXBElement<SimilarityQuery>(_SimilarityQuery_QNAME, SimilarityQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Segment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Segment")
    public JAXBElement<Segment> createSegment(Segment value) {
        return new JAXBElement<Segment>(_Segment_QNAME, Segment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Image }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Image")
    public JAXBElement<Image> createImage(Image value) {
        return new JAXBElement<Image>(_Image_QNAME, Image.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ComposedQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ComposedQuery")
    public JAXBElement<ComposedQuery> createComposedQuery(ComposedQuery value) {
        return new JAXBElement<ComposedQuery>(_ComposedQuery_QNAME, ComposedQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link MediaUnit }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "MediaUnit")
    public JAXBElement<MediaUnit> createMediaUnit(MediaUnit value) {
        return new JAXBElement<MediaUnit>(_MediaUnit_QNAME, MediaUnit.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Query }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Query")
    public JAXBElement<Query> createQuery(Query value) {
        return new JAXBElement<Query>(_Query_QNAME, Query.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ElementaryQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "ElementaryQuery")
    public JAXBElement<ElementaryQuery> createElementaryQuery(ElementaryQuery value) {
        return new JAXBElement<ElementaryQuery>(_ElementaryQuery_QNAME, ElementaryQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Audio }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Audio")
    public JAXBElement<Audio> createAudio(Audio value) {
        return new JAXBElement<Audio>(_Audio_QNAME, Audio.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Text }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Text")
    public JAXBElement<Text> createText(Text value) {
        return new JAXBElement<Text>(_Text_QNAME, Text.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Annotation }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Annotation")
    public JAXBElement<Annotation> createAnnotation(Annotation value) {
        return new JAXBElement<Annotation>(_Annotation_QNAME, Annotation.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link LinearSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "LinearSegment")
    public JAXBElement<LinearSegment> createLinearSegment(LinearSegment value) {
        return new JAXBElement<LinearSegment>(_LinearSegment_QNAME, LinearSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SpatioTemporalSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "SpatioTemporalSegment")
    public JAXBElement<SpatioTemporalSegment> createSpatioTemporalSegment(SpatioTemporalSegment value) {
        return new JAXBElement<SpatioTemporalSegment>(_SpatioTemporalSegment_QNAME, SpatioTemporalSegment.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link PieceOfKnowledge }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "PieceOfKnowledge")
    public JAXBElement<PieceOfKnowledge> createPieceOfKnowledge(PieceOfKnowledge value) {
        return new JAXBElement<PieceOfKnowledge>(_PieceOfKnowledge_QNAME, PieceOfKnowledge.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Document }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Document")
    public JAXBElement<Document> createDocument(Document value) {
        return new JAXBElement<Document>(_Document_QNAME, Document.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Resource }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "Resource")
    public JAXBElement<Resource> createResource(Resource value) {
        return new JAXBElement<Resource>(_Resource_QNAME, Resource.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link StringQuery }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "StringQuery")
    public JAXBElement<StringQuery> createStringQuery(StringQuery value) {
        return new JAXBElement<StringQuery>(_StringQuery_QNAME, StringQuery.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SpatialSegment }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://weblab.ow2.org/core/1.2/model#", name = "SpatialSegment")
    public JAXBElement<SpatialSegment> createSpatialSegment(SpatialSegment value) {
        return new JAXBElement<SpatialSegment>(_SpatialSegment_QNAME, SpatialSegment.class, null, value);
    }

}
